pub struct TrustedNodeAddress(pub *const c_void);Expand description
The address of a node known to be valid. These are sent from script to layout.
Tuple Fields
0: *const c_voidTrait Implementations
Sourceimpl Clone for TrustedNodeAddress
impl Clone for TrustedNodeAddress
Sourcefn clone(&self) -> TrustedNodeAddress
fn clone(&self) -> TrustedNodeAddress
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TrustedNodeAddress
Sourceimpl Debug for TrustedNodeAddress
impl Debug for TrustedNodeAddress
impl Eq for TrustedNodeAddress
Sourceimpl PartialEq for TrustedNodeAddress
impl PartialEq for TrustedNodeAddress
Sourcefn eq(&self, other: &TrustedNodeAddress) -> bool
fn eq(&self, other: &TrustedNodeAddress) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Send for TrustedNodeAddress
impl StructuralPartialEq for TrustedNodeAddress